package Image::FlickrSet;

use Image::Magick;
use LWP::Simple;

require Exporter;
our @ISA = qw(Exporter);
@EXPORT = qw(get_image);
@EXPORT_OK = qw();

use strict;
use warnings;

my %deffields = (
 imageDir => './snaps'
);

sub new
{
  my ($class,$photos, $options) = @_;
  my $self = {%deffields};
  $self->{photos} = $photos;
  foreach my $key (keys %{$options})
  {
  	$self->{$key} = $options->{$key};
  }
  bless $self, $class;
  
  # $self->{photokeys} = [sort keys %{$photos}];
  
  return $self;
}

sub make_url()
{
  my ($self, $idx, $minwidth) = @_;

	return '' if $idx > @{$self->{photos}};

  my $suffix = $minwidth <= 50? '_t' : '';


  my $photo = $self->{photos}->[$idx];
  return '' if !$photo;

  my $id = $photo->{id};

  return "http://static.flickr.com/$photo->{server}/${id}_$photo->{secret}$suffix.jpg";
}

sub make_filepath()
{
  my ($self, $idx, $minwidth, $makedirs) = @_;

  my $suffix = $minwidth <= 50? '_t' : '';

	return '' if $idx > @{$self->{photos}};

  # return '' if !(defined $self->{photokeys}->[$idx]);
  my $photo = $self->{photos}->[$idx];
  return '' if !$photo;

  my $id = $photo->{id};

  return "$self->{imageDir}/${id}$suffix.jpg";
}


sub download_image()
{
  my ($self, $idx, $minwidth) = @_;

  my $url = $self->make_url($idx, $minwidth);


  my $pimg;
	foreach (0..5)
	{
		$pimg = get $url;
		last if defined $pimg && $pimg ne '';
		print "Retry...\n" if $self->{verbose};
		sleep 1;
	}
  my $fname = $self->make_filepath($idx, $minwidth, 1);
  print "Adding $fname ...\n" if $self->{verbose};
	open (OFILE, ">$fname") || die ("can't open $fname");
	binmode OFILE;
	print OFILE $pimg;
	close OFILE;
}

sub get_image()
{
 my ($self, $idx, $minwidth) = @_;

  my $fname = $self->make_filepath($idx, $minwidth);
  return 0 if !$fname;

	if (!(-e $fname))
	{
		$self->download_image($idx, $minwidth);
	}
	my $image = Image::Magick->new;
	my $err = $image->Read($fname);
	warn "$err\n" if $err;
	return $image;
}

