#!/usr/bin/perl -s

#
# sub-sampling photo mosaic - Jim Bumgardner
#
# this script uses a subset of images from a larger set
# to make a mosaic against a target image
#
# work on reducing globals - store shared variables in an object...

use Image::Mosaic;
use Image::FlickrSet;

$photolist = shift;
$basepic = shift;
$max_images = shift;
$imagedir = shift;

$imagedir = $photolist if !$imagedir;
$photolist .= '.ph' if !($photolist =~ m/\.ph/);

$syntax = <<EOT;
pmosiac_subset.pl [options] <photolist> <basepic> [<max_images>]

Options:
  -dupesOK      Allow duplicate tiles
  -noborders    Reject images with solid-color borders or over 2:1 aspect ratio
  -noflops      Images may not be swapped horizontally
  -reso=\#      Subsamples per photo - default = 7
  -cellsize=\#  Size of tiles - default = 20
  
EOT

die "$syntax\n" if !$basepic;

require "${photolist}";

#
# these are all command line options
#
$reso = 7 if !$reso;  # number of subsamples per tile = reso x reso
$cellsize = 20 if !$cellsize;
$cellsize = 100 if $big;
$doflops = 1 if !$noflops && !$noflips;

$max_images = scalar(@photos)/4 if !$max_images;

my $imageset = Image::FlickrSet->new(\@photos, {imageDir => $imagedir, verbose=>1});

my $moz = Image::Mosaic->new({reso=>$reso,
                              max_images=>$max_images,
                              imageset=>$imageset,
                              basepic=>$basepic,
                              noborders=>$noborders,
                              doflops=>$doflops,
                              cellsize=>$cellsize,
                              verbose=>1
															});

$moz->generate_mosaic();

